from django.test import TestCase


class adminfieldsTest(TestCase):
    """
    Tests for django-admin-fields
    """
    def test_adminfields(self):
        pass